@@ -10,8 +10,8 @@ import logging
 import boto3
 from pathlib import Path
 import numpy as np
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
+from slack import WebClient
+from slack.errors import SlackApiError
 import keras
 from keras.callbacks import CSVLogger
 from Accuinsight.modeler.core import func, path, get
@@ -325,10 +325,10 @@ class accuinsight(object):
                 clear_runs(start_ts, end_ts, delta_ts)
                 accuinsight._send_message(metric = self.monitor,
                                           current_value = self.current_value,
-                                          message = self.message,
-                                          thresholds = self.thresholds,
-                                          token = self.token,
-                                          channel_id = self.channel_id)
+                                          message = message,
+                                          thresholds = thresholds,
+                                          token = token,
+                                          channel_id = channel_id)
                 modeler_rest = LifecycleRestApi(LcConst.BACK_END_API_URL,
                                                 LcConst.BACK_END_API_PORT,
                                                 LcConst.BACK_END_API_URI)
@@ -436,47 +436,23 @@ class accuinsight(object):
         gorilla.apply(gorilla.Patch(keras.Model, 'fit', fit, settings=settings))
 
 
-    def _send_message(metric=None, current_value=None, message=None, thresholds=None, token=None, channel_id=None):
-        
-        logger = logging.getLogger(__name__)
-        
+    def _send_message(metric = None, current_value = None, message = None, thresholds=None, token = None, channel_id = None):
         if token is not None and channel_id is not None:
-        
             if thresholds is not None:
                 try:
                     if current_value >= thresholds:
-                        msg = '[모델 학습 완료] ' + metric + '이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
+                        msg = '[모델 학습 완료] ' + metric +'이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
                         response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
                 except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
-                    
+                    assert e.response["error"]
             elif message is not None:
                 try:
                     msg = message
                     response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
                 except SlackApiError as e:
-                    logger.error(f"Error message: {e}")
-        else:
-            pass
-
-
-#    def _send_message(metric = None, current_value = None, message = None, thresholds=None, token = None, channel_id = None):
-#        if token is not None and channel_id is not None:
-#            if thresholds is not None:
-#                try:
-#                    if current_value >= thresholds:
-#                        msg = '[모델 학습 완료] ' + metric +'이 설정하신 thresolds: ' + str(thresholds) + '를 초과하였습니다.'
-#                        response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-#                except SlackApiError as e:
-#                    assert e.response["error"]
-#            elif message is not None:
-#                try:
-#                    msg = message
-#                    response = WebClient(token=token).chat_postMessage(channel=channel_id, text=msg)
-#                except SlackApiError as e:
-#                    assert e.response["error"]
-#            else:
-#                pass
+                    assert e.response["error"]
+            else:
+                pass
 
     def off_autolog():
         def stop_log(self, original, args, kwargs, unlogged_params):
