@@ -10,6 +10,7 @@ class AddDeployLog:
     """
         Object for adding deploy log.
     """
+
     def __init__(self):
         self.deploy_log = DeployLog()
         self.deploy_alarm = DeployAlarm()
@@ -23,17 +24,27 @@ class AddDeployLog:
         self.deploy_log.req_method = request.method
         self.deploy_log.req_url = request.url
 
-        req_data = dict()
+        req_data = list()
         if request.data:
-            req_data['input_data'] = request.data.decode('utf-8')
+            req_data.append(request.data.decode('utf-8'))
 
         if request.files:
-            req_data['input_files'] = request.files
+            req_data.append(dict(request.files))
 
         if request.form:
-            req_data['input_form'] = request.form
+            req_data.append(dict(request.form))
 
-        self.deploy_log.req_body = str(req_data)
+        if len(req_data) == 1:
+            req_str = str(req_data.pop())
+        elif len(req_data) == 0:
+            req_str = str()
+        else:
+            req_str = str(req_data)
+
+        try:
+            self.deploy_log.req_body = json.loads(req_str)
+        except json.decoder.JSONDecodeError:
+            self.deploy_log.req_body = req_str
 
         if "swagger" in request.url:
             self.swagger = True
@@ -46,9 +57,14 @@ class AddDeployLog:
         self.deploy_log.end_time = datetime.datetime.now().timestamp()
         self.deploy_log.status_code = str(response.status_code)
         try:
-            self.deploy_log.response_data = response.get_data().decode()
+            res_data = response.get_data().decode()
         except UnicodeDecodeError:
-            self.deploy_log.response_data = response.get_data()
+            res_data = response.get_data()
+
+        try:
+            self.deploy_log.response_data = json.loads(res_data)
+        except json.decoder.JSONDecodeError:
+            self.deploy_log.response_data = str(res_data)
 
     def add_log(self, messages, notifiers):
         if not self.swagger:
