@@ -26,7 +26,7 @@ class RestStore:
             return endpoint + '/monitoring'
 
     def call_endpoint(self, method, json_body, mode):
-        env_value = get_os_env('MONITORING_DEPLOY', env_path='/Users/a10053')
+        env_value = get_os_env('MONITORING_DEPLOY')
         endpoint = self.set_endpoint_uri('/project/{projectId}/deploy/{deployId}', mode)
         endpoint = endpoint.replace('{projectId}', str(env_value[DeployConst.ENV_PROJECT_ID]))
         endpoint = endpoint.replace('{deployId}', str(env_value[DeployConst.ENV_DEPLOY_ID]))
